@@ -4,10 +4,10 @@
 # To create a new version, update IPEVERS below and add a new entry in debian/changelog
 # Then run bash make-specs.sh, and upload the three files to build.opensuse.org
 
-IPEVERS="7.2.20"
+IPEVERS="7.2.24"
 DEBVERS="1"
 
-SOURCES=~/ipe-$IPEVERS-src.tar.gz
+SOURCES=~/LastIpeRelease/ipe-$IPEVERS-src.tar.gz
 
 ORIGFILE=ipe_$IPEVERS.orig.tar.gz
 DEBFILE=ipe_$IPEVERS-${DEBVERS}.debian.tar.xz
@@ -28,7 +28,7 @@ Binary: ipe
 Maintainer: Otfried Cheong <ipe@otfried.org>
 Architecture: any
 Homepage: http://ipe.otfried.org/
-Build-Depends: sharutils, debhelper (>= 9~), zlib1g-dev, qtbase5-dev, qtbase5-dev-tools, libfreetype6-dev, libcairo2-dev, libjpeg-dev, libpng-dev, liblua5.3-dev, libgsl-dev, libcurl4-openssl-dev, libfontconfig1-dev
+Build-Depends: sharutils, doxygen, debhelper (>= 9~), zlib1g-dev, qtbase5-dev, qtbase5-dev-tools, libfreetype6-dev, libcairo2-dev, libjpeg-dev, libpng-dev, liblua5.3-dev, libgsl-dev, libspiro-dev, libcurl4-openssl-dev, libfontconfig1-dev
 Files:
 EOF
 
