@@ -102,12 +102,13 @@ XmlOutputDev::~XmlOutputDev()
 
 void XmlOutputDev::setTextHandling(bool math, bool notext, 
                                    bool literal, int mergeLevel,
-                                   int unicodeLevel)
+				   bool noTextSize, int unicodeLevel)
 {
   iIsMath = math;
   iNoText = notext;
   iIsLiteral = literal;
   iMergeLevel = mergeLevel;
+  iNoTextSize = noTextSize;
   iUnicodeLevel = unicodeLevel;
   if (iUnicodeLevel >= 2) {
     writePS("<ipestyle>\n");
@@ -118,11 +119,6 @@ void XmlOutputDev::setTextHandling(bool math, bool notext,
 
 // ----------------------------------------------------------
 
-void XmlOutputDev::startPage(int pageNum, GfxState *state)
-{
-  startPage(pageNum, state, NULL);  // for poppler <= 0.22
-}
-
 void XmlOutputDev::startPage(int pageNum, GfxState *state, XRef *xrefA)
 {
   writePSFmt("<!-- Page: %d %d -->\n", pageNum, seqPage);
@@ -248,7 +244,7 @@ void XmlOutputDev::drawChar(GfxState *state, double x, double y,
 			    double dx, double dy,
 			    double originX, double originY,
 			    CharCode code, int nBytes, 
-			    Unicode *u, int uLen)
+			    const Unicode *u, int uLen)
 {
   // check for invisible text -- this is used by Acrobat Capture
   if ((state->getRender() & 3) == 3)
@@ -302,10 +298,13 @@ void XmlOutputDev::startText(GfxState *state, double x, double y)
 
   GfxRGB rgb;
   state->getFillRGB(&rgb);
-  writeColor("<text stroke=", rgb, " pos=\"0 0\" transformations=\"affine\" ");
+  writeColor("<text stroke=", rgb, " pos=\"0 0\" ");
+  if (iNoTextSize)
+    writePS("transformations=\"rigid\" ");
+  else
+    writePSFmt("transformations=\"affine\" size=\"%g\" ", state->getFontSize());
   writePS("valign=\"baseline\" ");
-  writePSFmt("size=\"%g\" matrix=\"%g %g %g %g %g %g\">",
-	     state->getFontSize(), M[0], M[1], M[2], M[3], xt, yt);
+  writePSFmt("matrix=\"%g %g %g %g %g %g\">", M[0], M[1], M[2], M[3], xt, yt);
 
   if (iIsMath)
     writePS("$");
@@ -326,7 +325,7 @@ void XmlOutputDev::finishText()
 
 void XmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str,
                              int width, int height, GfxImageColorMap *colorMap,
-                             bool interpolate, int *maskColors, 
+                             bool interpolate, const int *maskColors, 
                              bool inlineImg)
 {
   finishText();
